//---------------------------------------------------------------------------
#ifndef AnimTimerH
#define AnimTimerH
//---------------------------------------------------------------------------
#include <SysUtils.hpp>
#include <Controls.hpp>
#include <Classes.hpp>
#include <Forms.hpp>
//---------------------------------------------------------------------------

// TANIMTIMER is a fast multi-threaded timer for animation.
// It behaves like a regular TTimer but has two differences:
//  - You can set it to go a lot faster. If the computer isn't
//    up to the speed you ask of it, it will do the best it can.
//  - It never interferes with user-responsiveness. This timer
//    runs at a priority level slightly lower than that of the
//    user interface. Hence your timer events will never make
//    the application appear sluggish.
// There is one other small difference. Setting Interval to the
// special value of -1 means 'go flat out'.

class PACKAGE TAnimTimer : public TComponent
{
public:
  __fastcall TAnimTimer(TComponent* Owner);
  virtual __fastcall ~TAnimTimer();

__published:
  __property bool Enabled = {read=FEnabled,write=SetEnabled,default=true};
  __property unsigned int Interval = {read=FInterval,write=SetInterval,default=10};
  __property TNotifyEvent OnTimer = {read=FOnTimer,write=SetOnTimer};

protected:
  bool FEnabled;
  unsigned int FInterval;
  TNotifyEvent FOnTimer;
  virtual void __fastcall SetInterval(unsigned int newinterval);
  virtual void __fastcall SetEnabled(bool newenabled);
  virtual void __fastcall SetOnTimer(TNotifyEvent newevent);
  HWND hwnd;
  virtual void __fastcall Start();
  virtual void __fastcall Stop(); // blocking
  virtual void __fastcall Alert(); // blocking
  virtual void __fastcall LuWndProc(TMessage &Message);
  virtual void __fastcall UpdateTimer();
  virtual void __fastcall Timer();
  static void ThreadFunction(void *lParam);
};




//---------------------------------------------------------------------------
#endif